# Python WireMock Admin API Client

<p align="center">
    <a href="https://wiremock.org/docs/solutions/python/" target="_blank">
        <img width="512px" src="docs/images/python-wiremock-horizontal.png" alt="WireMock Logo"/>
    </a>
</p>

This is a python admin API client to a standalone WireMock server.

[![a](https://img.shields.io/badge/slack-%23wiremock%2Fpython-brightgreen?style=flat&logo=slack)](https://slack.wiremock.org/)
[![Coverage Status](https://coveralls.io/repos/github/wiremock/python-wiremock/badge.svg?branch=master)](https://coveralls.io/github/wiremock/python-wiremock?branch=master)
[![Docs](https://img.shields.io/badge/docs-latest-brightgreen.svg)](http://wiremock.readthedocs.org/)

## Install as Dependency

To install:

    pip install wiremock

## Documentation

wiremock documentation can be found at http://wiremock.readthedocs.org/

## Pull Requests

General Rules:

- All Tests must pass
- Coverage shouldn't decrease
- All Pull Requests should be rebased against master **before** submitting the PR.

## Development

Setup the project using poetry.

`poetry install`
